@@ -265,35 +265,35 @@ spec:
       labels:
         severity: warning
       annotations:
-        summary: CredentialsRequest(s) pointing to non-existant namespace
+        message: CredentialsRequest(s) pointing to non-existant namespace
     - alert: CloudCredentialOperatorProvisioningFailed
       expr: cco_credentials_requests_conditions{condition="CredentialsProvisionFailure"} > 0
       for: 5m
       labels:
         severity: warning
       annotations:
-        summary: CredentialsRequest(s) unable to be fulfilled
+        message: CredentialsRequest(s) unable to be fulfilled
     - alert: CloudCredentialOperatorDeprovisioningFailed
       expr: cco_credentials_requests_conditions{condition="CredentialsDeprovisionFailure"} > 0
       for: 5m
       labels:
         severity: warning
       annotations:
-        summary: CredentialsRequest(s) unable to be cleaned up
+        message: CredentialsRequest(s) unable to be cleaned up
     - alert: CloudCredentialOperatorInsufficientCloudCreds
       expr: cco_credentials_requests_conditions{condition="InsufficientCloudCreds"} > 0
       for: 5m
       labels:
         severity: warning
       annotations:
-        summary: Cluster's cloud credentials insufficient for minting or passthrough
+        message: Cluster's cloud credentials insufficient for minting or passthrough
     - alert: CloudCredentialOperatorDown
       expr: absent(up{job="cco-metrics"} == 1)
       for: 5m
       labels:
         severity: critical
       annotations:
-        summary: cloud-credential-operator pod not running
+        message: cloud-credential-operator pod not running
 `)
 
 func config_manager_prometheusrule_yaml() ([]byte, error) {
@@ -327,13 +327,9 @@ metadata:
   namespace: openshift-cloud-credential-operator
 spec:
   endpoints:
-  - bearerTokenFile: /var/run/secrets/kubernetes.io/serviceaccount/token
-    interval: 30s
+  - interval: 30s
     port: cco-metrics
     scheme: http
-    tlsConfig:
-      caFile: /etc/prometheus/configmaps/serving-certs-ca-bundle/service-ca.crt
-      serverName: cco.openshift-cloud-credential-operator.svc
   namespaceSelector:
     matchNames:
     - openshift-cloud-credential-operator
